@@ -9,7 +9,7 @@ use File::Spec::Functions qw( tmpdir );
 use Cache::SizeAwareFileCache;
 use Storable qw( freeze );
 
-$VERSION = '1.30';
+$VERSION = '1.40';
 
 # --------------------------------------------------------------------------
 
@@ -409,6 +409,15 @@ sub invalidate_cache_entry
 
 # --------------------------------------------------------------------------
 
+sub clear
+{
+  $CGI::Cache::THE_CACHE->clear();
+
+  return 1;
+}
+
+# --------------------------------------------------------------------------
+
 sub buffer
 {
   $THE_CAPTURED_OUTPUT = join( '', @_ ) if @_;
@@ -857,6 +866,11 @@ returns 1. It doesn't make much sense to call this after calling start(), as
 CGI::Cache will have already determined that the cache entry is invalid.
 
 
+=item $status = clear_cache();
+
+Deletes the cache. It is always successful, and always returns 1.
+
+
 =head1 CGI::Cache and Persistent Environments
 
 CGI::Cache supports persistent environments. The key is the return value from
